summaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/android/window_android.h2
-rw-r--r--ui/app_list/app_list_item.h2
-rw-r--r--ui/app_list/app_list_item_list.h2
-rw-r--r--ui/app_list/app_list_model.h2
-rw-r--r--ui/app_list/folder_image.h2
-rw-r--r--ui/app_list/pagination_model.h2
-rw-r--r--ui/app_list/search/history_data.h2
-rw-r--r--ui/app_list/search_box_model.h2
-rw-r--r--ui/app_list/search_result.h2
-rw-r--r--ui/app_list/speech_ui_model.h2
-rw-r--r--ui/app_list/test/app_list_test_view_delegate.h2
-rw-r--r--ui/app_list/views/app_list_view.h2
-rw-r--r--ui/app_list/views/top_icon_animation_view.h2
-rw-r--r--ui/aura/env.h2
-rw-r--r--ui/aura/test/test_cursor_client.h2
-rw-r--r--ui/aura/window.cc2
-rw-r--r--ui/aura/window.h2
-rw-r--r--ui/aura/window_tree_host.h2
-rw-r--r--ui/base/ime/chromeos/ime_keyboard.h2
-rw-r--r--ui/base/ime/input_method_base.h2
-rw-r--r--ui/base/ime/mock_input_method.h2
-rw-r--r--ui/base/ime/remote_input_method_win.cc2
-rw-r--r--ui/base/models/list_model.h2
-rw-r--r--ui/base/models/tree_node_model.h2
-rw-r--r--ui/base/user_activity/user_activity_detector.h2
-rw-r--r--ui/chromeos/ime/candidate_window_view.h2
-rw-r--r--ui/chromeos/ime/input_method_menu_manager.h2
-rw-r--r--ui/chromeos/network/network_icon_animation.h2
-rw-r--r--ui/compositor/compositor.h4
-rw-r--r--ui/compositor/compositor_vsync_manager.h2
-rw-r--r--ui/compositor/layer_animation_sequence.h2
-rw-r--r--ui/compositor/layer_animator.h2
-rw-r--r--ui/display/chromeos/display_configurator.h2
-rw-r--r--ui/display/chromeos/x11/native_display_delegate_x11.h2
-rw-r--r--ui/events/devices/device_data_manager.h2
-rw-r--r--ui/events/ozone/device/device_manager_manual.h2
-rw-r--r--ui/events/ozone/device/udev/device_manager_udev.h2
-rw-r--r--ui/events/platform/platform_event_source.cc2
-rw-r--r--ui/events/platform/platform_event_source.h8
-rw-r--r--ui/gfx/display_change_notifier.h2
-rw-r--r--ui/gfx/sys_color_change_listener.cc2
-rw-r--r--ui/gfx/win/singleton_hwnd.h2
-rw-r--r--ui/gl/gpu_switching_manager.h2
-rw-r--r--ui/keyboard/keyboard_controller.h2
-rw-r--r--ui/message_center/message_center_impl.h2
-rw-r--r--ui/message_center/notification_blocker.h2
-rw-r--r--ui/native_theme/native_theme.h2
-rw-r--r--ui/ozone/platform/drm/host/drm_gpu_platform_support_host.h2
-rw-r--r--ui/ozone/platform/drm/host/drm_native_display_delegate.h2
-rw-r--r--ui/snapshot/screenshot_grabber.h2
-rw-r--r--ui/views/animation/bounds_animator.h2
-rw-r--r--ui/views/controls/menu/native_menu_win.h2
-rw-r--r--ui/views/focus/focus_manager.h2
-rw-r--r--ui/views/focus/widget_focus_manager.h2
-rw-r--r--ui/views/widget/desktop_aura/desktop_window_tree_host_x11.h2
-rw-r--r--ui/views/widget/widget.h4
-rw-r--r--ui/views/win/windows_session_change_observer.cc2
-rw-r--r--ui/wm/core/compound_event_filter.h2
-rw-r--r--ui/wm/core/cursor_manager.h2
-rw-r--r--ui/wm/core/default_activation_client.h2
-rw-r--r--ui/wm/core/focus_controller.h5
-rw-r--r--ui/wm/core/transient_window_manager.h2
62 files changed, 70 insertions, 67 deletions
diff --git a/ui/android/window_android.h b/ui/android/window_android.h
index 005f4d6..a69a1dd 100644
--- a/ui/android/window_android.h
+++ b/ui/android/window_android.h
@@ -70,7 +70,7 @@ class UI_ANDROID_EXPORT WindowAndroid {
gfx::Vector2dF content_offset_;
WindowAndroidCompositor* compositor_;
- ObserverList<WindowAndroidObserver> observer_list_;
+ base::ObserverList<WindowAndroidObserver> observer_list_;
DISALLOW_COPY_AND_ASSIGN(WindowAndroid);
};
diff --git a/ui/app_list/app_list_item.h b/ui/app_list/app_list_item.h
index ab5632f..ea476bb88d 100644
--- a/ui/app_list/app_list_item.h
+++ b/ui/app_list/app_list_item.h
@@ -133,7 +133,7 @@ class APP_LIST_EXPORT AppListItem {
bool is_installing_;
int percent_downloaded_;
- ObserverList<AppListItemObserver> observers_;
+ base::ObserverList<AppListItemObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(AppListItem);
};
diff --git a/ui/app_list/app_list_item_list.h b/ui/app_list/app_list_item_list.h
index c4ad1d5..32b434e 100644
--- a/ui/app_list/app_list_item_list.h
+++ b/ui/app_list/app_list_item_list.h
@@ -106,7 +106,7 @@ class APP_LIST_EXPORT AppListItemList {
void FixItemPosition(size_t index);
ScopedVector<AppListItem> app_list_items_;
- ObserverList<AppListItemListObserver, true> observers_;
+ base::ObserverList<AppListItemListObserver, true> observers_;
std::string highlighted_id_;
DISALLOW_COPY_AND_ASSIGN(AppListItemList);
diff --git a/ui/app_list/app_list_model.h b/ui/app_list/app_list_model.h
index 0bfd790..3845f5a 100644
--- a/ui/app_list/app_list_model.h
+++ b/ui/app_list/app_list_model.h
@@ -220,7 +220,7 @@ class APP_LIST_EXPORT AppListModel : public AppListItemListObserver {
Status status_;
State state_;
- ObserverList<AppListModelObserver, true> observers_;
+ base::ObserverList<AppListModelObserver, true> observers_;
bool folders_enabled_;
bool custom_launcher_page_enabled_;
std::string custom_launcher_page_name_;
diff --git a/ui/app_list/folder_image.h b/ui/app_list/folder_image.h
index 1842d97..785c690 100644
--- a/ui/app_list/folder_image.h
+++ b/ui/app_list/folder_image.h
@@ -93,7 +93,7 @@ class APP_LIST_EXPORT FolderImage : public AppListItemListObserver,
// Top items for generating folder icon.
std::vector<AppListItem*> top_items_;
- ObserverList<FolderImageObserver> observers_;
+ base::ObserverList<FolderImageObserver> observers_;
};
} // namespace app_list
diff --git a/ui/app_list/pagination_model.h b/ui/app_list/pagination_model.h
index 13c47ab..1959858 100644
--- a/ui/app_list/pagination_model.h
+++ b/ui/app_list/pagination_model.h
@@ -142,7 +142,7 @@ class APP_LIST_EXPORT PaginationModel : public gfx::AnimationDelegate {
int last_overscroll_target_page_;
base::TimeTicks last_overscroll_animation_start_time_;
- ObserverList<PaginationModelObserver> observers_;
+ base::ObserverList<PaginationModelObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(PaginationModel);
};
diff --git a/ui/app_list/search/history_data.h b/ui/app_list/search/history_data.h
index f0932fc..deaa6ac 100644
--- a/ui/app_list/search/history_data.h
+++ b/ui/app_list/search/history_data.h
@@ -82,7 +82,7 @@ class APP_LIST_EXPORT HistoryData : public base::SupportsWeakPtr<HistoryData> {
HistoryDataStore* store_; // Not owned.
const size_t max_primary_;
const size_t max_secondary_;
- ObserverList<HistoryDataObserver, true> observers_;
+ base::ObserverList<HistoryDataObserver, true> observers_;
Associations associations_;
diff --git a/ui/app_list/search_box_model.h b/ui/app_list/search_box_model.h
index 9faaab2..cd35e70 100644
--- a/ui/app_list/search_box_model.h
+++ b/ui/app_list/search_box_model.h
@@ -87,7 +87,7 @@ class APP_LIST_EXPORT SearchBoxModel {
gfx::SelectionModel selection_model_;
base::string16 text_;
- ObserverList<SearchBoxModelObserver> observers_;
+ base::ObserverList<SearchBoxModelObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(SearchBoxModel);
};
diff --git a/ui/app_list/search_result.h b/ui/app_list/search_result.h
index 69c9db4..a09e186 100644
--- a/ui/app_list/search_result.h
+++ b/ui/app_list/search_result.h
@@ -195,7 +195,7 @@ class APP_LIST_EXPORT SearchResult {
bool is_installing_;
int percent_downloaded_;
- ObserverList<SearchResultObserver> observers_;
+ base::ObserverList<SearchResultObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(SearchResult);
};
diff --git a/ui/app_list/speech_ui_model.h b/ui/app_list/speech_ui_model.h
index 353796d..9ee7e86 100644
--- a/ui/app_list/speech_ui_model.h
+++ b/ui/app_list/speech_ui_model.h
@@ -52,7 +52,7 @@ class APP_LIST_EXPORT SpeechUIModel {
int16 minimum_sound_level_;
int16 maximum_sound_level_;
- ObserverList<SpeechUIModelObserver> observers_;
+ base::ObserverList<SpeechUIModelObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(SpeechUIModel);
};
diff --git a/ui/app_list/test/app_list_test_view_delegate.h b/ui/app_list/test/app_list_test_view_delegate.h
index 54239a9..cc2670c 100644
--- a/ui/app_list/test/app_list_test_view_delegate.h
+++ b/ui/app_list/test/app_list_test_view_delegate.h
@@ -102,7 +102,7 @@ class AppListTestViewDelegate : public AppListViewDelegate {
std::map<size_t, int> open_search_result_counts_;
Users users_;
scoped_ptr<AppListTestModel> model_;
- ObserverList<AppListViewDelegateObserver> observers_;
+ base::ObserverList<AppListViewDelegateObserver> observers_;
SpeechUIModel speech_ui_;
base::TimeDelta auto_launch_timeout_;
diff --git a/ui/app_list/views/app_list_view.h b/ui/app_list/views/app_list_view.h
index 27e6e8a..6c3dfc7 100644
--- a/ui/app_list/views/app_list_view.h
+++ b/ui/app_list/views/app_list_view.h
@@ -181,7 +181,7 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDelegateView,
// open.
views::View* overlay_view_;
- ObserverList<AppListViewObserver> observers_;
+ base::ObserverList<AppListViewObserver> observers_;
scoped_ptr<HideViewAnimationObserver> animation_observer_;
// For UMA and testing. If non-null, triggered when the app list is painted.
diff --git a/ui/app_list/views/top_icon_animation_view.h b/ui/app_list/views/top_icon_animation_view.h
index 787b384..eea32db 100644
--- a/ui/app_list/views/top_icon_animation_view.h
+++ b/ui/app_list/views/top_icon_animation_view.h
@@ -68,7 +68,7 @@ class TopIconAnimationView : public views::View,
// true: opening folder; false: closing folder.
bool open_folder_;
- ObserverList<TopIconAnimationObserver> observers_;
+ base::ObserverList<TopIconAnimationObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(TopIconAnimationView);
};
diff --git a/ui/aura/env.h b/ui/aura/env.h
index 9b84c3b..6fbcb17 100644
--- a/ui/aura/env.h
+++ b/ui/aura/env.h
@@ -93,7 +93,7 @@ class AURA_EXPORT Env : public ui::EventTarget, public base::SupportsUserData {
scoped_ptr<ui::EventTargetIterator> GetChildIterator() const override;
ui::EventTargeter* GetEventTargeter() override;
- ObserverList<EnvObserver> observers_;
+ base::ObserverList<EnvObserver> observers_;
int mouse_button_flags_;
// Location of last mouse event, in screen coordinates.
diff --git a/ui/aura/test/test_cursor_client.h b/ui/aura/test/test_cursor_client.h
index b741455..c5412d2 100644
--- a/ui/aura/test/test_cursor_client.h
+++ b/ui/aura/test/test_cursor_client.h
@@ -56,7 +56,7 @@ class TestCursorClient : public aura::client::CursorClient {
bool mouse_events_enabled_;
int cursor_lock_count_;
int calls_to_set_cursor_;
- ObserverList<aura::client::CursorClientObserver> observers_;
+ base::ObserverList<aura::client::CursorClientObserver> observers_;
aura::Window* root_window_;
DISALLOW_COPY_AND_ASSIGN(TestCursorClient);
diff --git a/ui/aura/window.cc b/ui/aura/window.cc
index 69bddfd..1e293b7 100644
--- a/ui/aura/window.cc
+++ b/ui/aura/window.cc
@@ -197,7 +197,7 @@ Window::Window(WindowDelegate* delegate)
// Don't notify newly added observers during notification. This causes
// problems for code that adds an observer as part of an observer
// notification (such as the workspace code).
- observers_(ObserverList<WindowObserver>::NOTIFY_EXISTING_ONLY) {
+ observers_(base::ObserverList<WindowObserver>::NOTIFY_EXISTING_ONLY) {
set_target_handler(delegate_);
}
diff --git a/ui/aura/window.h b/ui/aura/window.h
index 42cab33..0a82a02 100644
--- a/ui/aura/window.h
+++ b/ui/aura/window.h
@@ -532,7 +532,7 @@ class AURA_EXPORT Window : public ui::LayerDelegate,
// See set_hit_test_bounds_override_inner().
gfx::Insets hit_test_bounds_override_inner_;
- ObserverList<WindowObserver, true> observers_;
+ base::ObserverList<WindowObserver, true> observers_;
// Value struct to keep the name and deallocator for this property.
// Key cannot be used for this purpose because it can be char* or
diff --git a/ui/aura/window_tree_host.h b/ui/aura/window_tree_host.h
index 0d09093..f4dc23e 100644
--- a/ui/aura/window_tree_host.h
+++ b/ui/aura/window_tree_host.h
@@ -180,7 +180,7 @@ class AURA_EXPORT WindowTreeHost {
// the dtor).
Window* window_; // Owning.
- ObserverList<WindowTreeHostObserver> observers_;
+ base::ObserverList<WindowTreeHostObserver> observers_;
scoped_ptr<WindowEventDispatcher> dispatcher_;
diff --git a/ui/base/ime/chromeos/ime_keyboard.h b/ui/base/ime/chromeos/ime_keyboard.h
index 2c0e912..2885a2a 100644
--- a/ui/base/ime/chromeos/ime_keyboard.h
+++ b/ui/base/ime/chromeos/ime_keyboard.h
@@ -116,7 +116,7 @@ class UI_BASE_IME_EXPORT ImeKeyboard {
std::string last_layout_;
private:
- ObserverList<Observer> observers_;
+ base::ObserverList<Observer> observers_;
};
} // namespace input_method
diff --git a/ui/base/ime/input_method_base.h b/ui/base/ime/input_method_base.h
index 6378388..eb81738 100644
--- a/ui/base/ime/input_method_base.h
+++ b/ui/base/ime/input_method_base.h
@@ -95,7 +95,7 @@ class UI_BASE_IME_EXPORT InputMethodBase
internal::InputMethodDelegate* delegate_;
TextInputClient* text_input_client_;
- ObserverList<InputMethodObserver> observer_list_;
+ base::ObserverList<InputMethodObserver> observer_list_;
bool system_toplevel_window_focused_;
diff --git a/ui/base/ime/mock_input_method.h b/ui/base/ime/mock_input_method.h
index 67cc299..305a80f 100644
--- a/ui/base/ime/mock_input_method.h
+++ b/ui/base/ime/mock_input_method.h
@@ -56,7 +56,7 @@ class UI_BASE_IME_EXPORT MockInputMethod
private:
TextInputClient* text_input_client_;
- ObserverList<InputMethodObserver> observer_list_;
+ base::ObserverList<InputMethodObserver> observer_list_;
DISALLOW_COPY_AND_ASSIGN(MockInputMethod);
};
diff --git a/ui/base/ime/remote_input_method_win.cc b/ui/base/ime/remote_input_method_win.cc
index 9735b0e..4f0ab62 100644
--- a/ui/base/ime/remote_input_method_win.cc
+++ b/ui/base/ime/remote_input_method_win.cc
@@ -338,7 +338,7 @@ class RemoteInputMethodWin : public InputMethod,
remote_delegate_;
}
- ObserverList<InputMethodObserver> observer_list_;
+ base::ObserverList<InputMethodObserver> observer_list_;
internal::InputMethodDelegate* delegate_;
internal::RemoteInputMethodDelegateWin* remote_delegate_;
diff --git a/ui/base/models/list_model.h b/ui/base/models/list_model.h
index e358d84..6ed660f 100644
--- a/ui/base/models/list_model.h
+++ b/ui/base/models/list_model.h
@@ -134,7 +134,7 @@ class ListModel {
private:
ScopedVector<ItemType> items_;
- ObserverList<ListModelObserver> observers_;
+ base::ObserverList<ListModelObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(ListModel<ItemType>);
};
diff --git a/ui/base/models/tree_node_model.h b/ui/base/models/tree_node_model.h
index 3ebbcee..5118578 100644
--- a/ui/base/models/tree_node_model.h
+++ b/ui/base/models/tree_node_model.h
@@ -292,7 +292,7 @@ class TreeNodeModel : public TreeModel {
private:
// The observers.
- ObserverList<TreeModelObserver> observer_list_;
+ base::ObserverList<TreeModelObserver> observer_list_;
// The root.
scoped_ptr<NodeType> root_;
diff --git a/ui/base/user_activity/user_activity_detector.h b/ui/base/user_activity/user_activity_detector.h
index a7665a8..4ec398f9 100644
--- a/ui/base/user_activity/user_activity_detector.h
+++ b/ui/base/user_activity/user_activity_detector.h
@@ -62,7 +62,7 @@ class UI_BASE_EXPORT UserActivityDetector : public ui::PlatformEventObserver {
// since the last notification.
void HandleActivity(const ui::Event* event);
- ObserverList<UserActivityObserver> observers_;
+ base::ObserverList<UserActivityObserver> observers_;
// Last time at which user activity was observed.
base::TimeTicks last_activity_time_;
diff --git a/ui/chromeos/ime/candidate_window_view.h b/ui/chromeos/ime/candidate_window_view.h
index e4846fe..6861e1b 100644
--- a/ui/chromeos/ime/candidate_window_view.h
+++ b/ui/chromeos/ime/candidate_window_view.h
@@ -93,7 +93,7 @@ class UI_CHROMEOS_EXPORT CandidateWindowView : public views::BubbleDelegateView,
int selected_candidate_index_in_page_;
// The observers of the object.
- ObserverList<Observer> observers_;
+ base::ObserverList<Observer> observers_;
// Views created in the class will be part of tree of |this|, so these
// child views will be deleted when |this| is deleted.
diff --git a/ui/chromeos/ime/input_method_menu_manager.h b/ui/chromeos/ime/input_method_menu_manager.h
index c1de537..3c3ddb4 100644
--- a/ui/chromeos/ime/input_method_menu_manager.h
+++ b/ui/chromeos/ime/input_method_menu_manager.h
@@ -53,7 +53,7 @@ public:
InputMethodMenuItemList menu_list_;
// Observers who will be notified when menu changes.
- ObserverList<Observer> observers_;
+ base::ObserverList<Observer> observers_;
DISALLOW_COPY_AND_ASSIGN(InputMethodMenuManager);
};
diff --git a/ui/chromeos/network/network_icon_animation.h b/ui/chromeos/network/network_icon_animation.h
index 56ed2a2..f37791b 100644
--- a/ui/chromeos/network/network_icon_animation.h
+++ b/ui/chromeos/network/network_icon_animation.h
@@ -39,7 +39,7 @@ class UI_CHROMEOS_EXPORT NetworkIconAnimation : public gfx::AnimationDelegate {
private:
gfx::ThrobAnimation animation_;
- ObserverList<AnimationObserver> observers_;
+ base::ObserverList<AnimationObserver> observers_;
};
} // namespace network_icon
diff --git a/ui/compositor/compositor.h b/ui/compositor/compositor.h
index 3101bc2..e82c49d 100644
--- a/ui/compositor/compositor.h
+++ b/ui/compositor/compositor.h
@@ -334,8 +334,8 @@ class COMPOSITOR_EXPORT Compositor
// The root of the Layer tree drawn by this compositor.
Layer* root_layer_;
- ObserverList<CompositorObserver, true> observer_list_;
- ObserverList<CompositorAnimationObserver> animation_observer_list_;
+ base::ObserverList<CompositorObserver, true> observer_list_;
+ base::ObserverList<CompositorAnimationObserver> animation_observer_list_;
std::list<CompositorBeginFrameObserver*> begin_frame_observer_list_;
gfx::AcceleratedWidget widget_;
diff --git a/ui/compositor/compositor_vsync_manager.h b/ui/compositor/compositor_vsync_manager.h
index 7e9e07b..9f3e688 100644
--- a/ui/compositor/compositor_vsync_manager.h
+++ b/ui/compositor/compositor_vsync_manager.h
@@ -51,7 +51,7 @@ class COMPOSITOR_EXPORT CompositorVSyncManager
void NotifyObservers(base::TimeTicks timebase, base::TimeDelta interval);
- ObserverList<Observer> observer_list_;
+ base::ObserverList<Observer> observer_list_;
base::TimeTicks last_timebase_;
base::TimeDelta last_interval_;
diff --git a/ui/compositor/layer_animation_sequence.h b/ui/compositor/layer_animation_sequence.h
index 19635ad..0dad650 100644
--- a/ui/compositor/layer_animation_sequence.h
+++ b/ui/compositor/layer_animation_sequence.h
@@ -176,7 +176,7 @@ class COMPOSITOR_EXPORT LayerAnimationSequence
int animation_group_id_;
// These parties are notified when layer animations end.
- ObserverList<LayerAnimationObserver> observers_;
+ base::ObserverList<LayerAnimationObserver> observers_;
// Tracks the last_progressed_fraction() of the most recently progressed
// element.
diff --git a/ui/compositor/layer_animator.h b/ui/compositor/layer_animator.h
index 69744f8..99b3765 100644
--- a/ui/compositor/layer_animator.h
+++ b/ui/compositor/layer_animator.h
@@ -349,7 +349,7 @@ class COMPOSITOR_EXPORT LayerAnimator : public base::RefCounted<LayerAnimator> {
// Observers are notified when layer animations end, are scheduled or are
// aborted.
- ObserverList<LayerAnimationObserver> observers_;
+ base::ObserverList<LayerAnimationObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(LayerAnimator);
};
diff --git a/ui/display/chromeos/display_configurator.h b/ui/display/chromeos/display_configurator.h
index d185301..5564aa3 100644
--- a/ui/display/chromeos/display_configurator.h
+++ b/ui/display/chromeos/display_configurator.h
@@ -398,7 +398,7 @@ class DISPLAY_EXPORT DisplayConfigurator : public NativeDisplayObserver {
// Most-recently-used framebuffer size.
gfx::Size framebuffer_size_;
- ObserverList<Observer> observers_;
+ base::ObserverList<Observer> observers_;
// The timer to delay configuring displays. This is used to aggregate multiple
// display configuration events when they are reported in short time spans.
diff --git a/ui/display/chromeos/x11/native_display_delegate_x11.h b/ui/display/chromeos/x11/native_display_delegate_x11.h
index d201e5a..fadcf56 100644
--- a/ui/display/chromeos/x11/native_display_delegate_x11.h
+++ b/ui/display/chromeos/x11/native_display_delegate_x11.h
@@ -163,7 +163,7 @@ class DISPLAY_EXPORT NativeDisplayDelegateX11 : public NativeDisplayDelegate {
scoped_ptr<NativeDisplayEventDispatcherX11> platform_event_dispatcher_;
// List of observers waiting for display configuration change events.
- ObserverList<NativeDisplayObserver> observers_;
+ base::ObserverList<NativeDisplayObserver> observers_;
// A background color used during boot time + multi displays.
uint32_t background_color_argb_;
diff --git a/ui/events/devices/device_data_manager.h b/ui/events/devices/device_data_manager.h
index 674676e..e8092aa 100644
--- a/ui/events/devices/device_data_manager.h
+++ b/ui/events/devices/device_data_manager.h
@@ -88,7 +88,7 @@ class EVENTS_DEVICES_EXPORT DeviceDataManager
std::vector<InputDevice> mouse_devices_;
std::vector<InputDevice> touchpad_devices_;
- ObserverList<InputDeviceEventObserver> observers_;
+ base::ObserverList<InputDeviceEventObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(DeviceDataManager);
};
diff --git a/ui/events/ozone/device/device_manager_manual.h b/ui/events/ozone/device/device_manager_manual.h
index d158365..5e59c55 100644
--- a/ui/events/ozone/device/device_manager_manual.h
+++ b/ui/events/ozone/device/device_manager_manual.h
@@ -32,7 +32,7 @@ class DeviceManagerManual : public DeviceManager {
bool have_scanned_devices_;
std::vector<base::FilePath> devices_;
- ObserverList<DeviceEventObserver> observers_;
+ base::ObserverList<DeviceEventObserver> observers_;
base::WeakPtrFactory<DeviceManagerManual> weak_ptr_factory_;
diff --git a/ui/events/ozone/device/udev/device_manager_udev.h b/ui/events/ozone/device/udev/device_manager_udev.h
index f3922db..8031c80 100644
--- a/ui/events/ozone/device/udev/device_manager_udev.h
+++ b/ui/events/ozone/device/udev/device_manager_udev.h
@@ -41,7 +41,7 @@ class DeviceManagerUdev
base::MessagePumpLibevent::FileDescriptorWatcher controller_;
- ObserverList<DeviceEventObserver> observers_;
+ base::ObserverList<DeviceEventObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(DeviceManagerUdev);
};
diff --git a/ui/events/platform/platform_event_source.cc b/ui/events/platform/platform_event_source.cc
index bf957f0..99f69ac 100644
--- a/ui/events/platform/platform_event_source.cc
+++ b/ui/events/platform/platform_event_source.cc
@@ -76,7 +76,7 @@ uint32_t PlatformEventSource::DispatchEvent(PlatformEvent platform_event) {
if ((action & POST_DISPATCH_PERFORM_DEFAULT) &&
dispatchers_.might_have_observers()) {
- ObserverList<PlatformEventDispatcher>::Iterator iter(&dispatchers_);
+ base::ObserverList<PlatformEventDispatcher>::Iterator iter(&dispatchers_);
while (PlatformEventDispatcher* dispatcher = iter.GetNext()) {
if (dispatcher->CanDispatchEvent(platform_event))
action = dispatcher->DispatchEvent(platform_event);
diff --git a/ui/gfx/display_change_notifier.h b/ui/gfx/display_change_notifier.h
index 041f0f7..2a93217 100644
--- a/ui/gfx/display_change_notifier.h
+++ b/ui/gfx/display_change_notifier.h
@@ -32,7 +32,7 @@ class GFX_EXPORT DisplayChangeNotifier {
private:
// The observers that need to be notified when a display is modified, added
// or removed.
- ObserverList<DisplayObserver> observer_list_;
+ base::ObserverList<DisplayObserver> observer_list_;
DISALLOW_COPY_AND_ASSIGN(DisplayChangeNotifier);
};
diff --git a/ui/gfx/sys_color_change_listener.cc b/ui/gfx/sys_color_change_listener.cc
index 5291a1e..771e5c0 100644
--- a/ui/gfx/sys_color_change_listener.cc
+++ b/ui/gfx/sys_color_change_listener.cc
@@ -67,7 +67,7 @@ class SysColorChangeObserver {
void OnWndProc(HWND hwnd, UINT message, WPARAM wparam, LPARAM lparam);
- ObserverList<SysColorChangeListener> listeners_;
+ base::ObserverList<SysColorChangeListener> listeners_;
scoped_ptr<gfx::SingletonHwndObserver> singleton_hwnd_observer_;
};
diff --git a/ui/gfx/win/singleton_hwnd.h b/ui/gfx/win/singleton_hwnd.h
index 789a60f..ea62b3e 100644
--- a/ui/gfx/win/singleton_hwnd.h
+++ b/ui/gfx/win/singleton_hwnd.h
@@ -44,7 +44,7 @@ class GFX_EXPORT SingletonHwnd : public WindowImpl {
void RemoveObserver(SingletonHwndObserver* observer);
// List of registered observers.
- ObserverList<SingletonHwndObserver, true> observer_list_;
+ base::ObserverList<SingletonHwndObserver, true> observer_list_;
DISALLOW_COPY_AND_ASSIGN(SingletonHwnd);
};
diff --git a/ui/gl/gpu_switching_manager.h b/ui/gl/gpu_switching_manager.h
index 3f1acc2..ba60945 100644
--- a/ui/gl/gpu_switching_manager.h
+++ b/ui/gl/gpu_switching_manager.h
@@ -71,7 +71,7 @@ class GL_EXPORT GpuSwitchingManager {
struct PlatformSpecific;
scoped_ptr<PlatformSpecific> platform_specific_;
- ObserverList<GpuSwitchingObserver> observer_list_;
+ base::ObserverList<GpuSwitchingObserver> observer_list_;
DISALLOW_COPY_AND_ASSIGN(GpuSwitchingManager);
};
diff --git a/ui/keyboard/keyboard_controller.h b/ui/keyboard/keyboard_controller.h
index 41650cc..a5156bb 100644
--- a/ui/keyboard/keyboard_controller.h
+++ b/ui/keyboard/keyboard_controller.h
@@ -181,7 +181,7 @@ class KEYBOARD_EXPORT KeyboardController : public ui::InputMethodObserver,
KeyboardMode keyboard_mode_;
ui::TextInputType type_;
- ObserverList<KeyboardControllerObserver> observer_list_;
+ base::ObserverList<KeyboardControllerObserver> observer_list_;
// The currently used keyboard position.
gfx::Rect current_keyboard_bounds_;
diff --git a/ui/message_center/message_center_impl.h b/ui/message_center/message_center_impl.h
index d84e514..272ea2c 100644
--- a/ui/message_center/message_center_impl.h
+++ b/ui/message_center/message_center_impl.h
@@ -215,7 +215,7 @@ class MessageCenterImpl : public MessageCenter,
scoped_ptr<NotificationList> notification_list_;
NotificationCache notification_cache_;
- ObserverList<MessageCenterObserver> observer_list_;
+ base::ObserverList<MessageCenterObserver> observer_list_;
scoped_ptr<internal::PopupTimersController> popup_timers_controller_;
scoped_ptr<base::OneShotTimer<MessageCenterImpl> > quiet_mode_timer_;
NotifierSettingsProvider* settings_provider_;
diff --git a/ui/message_center/notification_blocker.h b/ui/message_center/notification_blocker.h
index 385b985..4bcb361 100644
--- a/ui/message_center/notification_blocker.h
+++ b/ui/message_center/notification_blocker.h
@@ -47,7 +47,7 @@ class MESSAGE_CENTER_EXPORT NotificationBlocker {
void NotifyBlockingStateChanged();
private:
- ObserverList<Observer> observers_;
+ base::ObserverList<Observer> observers_;
MessageCenter* message_center_; // weak
};
diff --git a/ui/native_theme/native_theme.h b/ui/native_theme/native_theme.h
index 75d9820..9ceae9d 100644
--- a/ui/native_theme/native_theme.h
+++ b/ui/native_theme/native_theme.h
@@ -360,7 +360,7 @@ class NATIVE_THEME_EXPORT NativeTheme {
private:
// Observers to notify when the native theme changes.
- ObserverList<NativeThemeObserver> native_theme_observers_;
+ base::ObserverList<NativeThemeObserver> native_theme_observers_;
DISALLOW_COPY_AND_ASSIGN(NativeTheme);
};
diff --git a/ui/ozone/platform/drm/host/drm_gpu_platform_support_host.h b/ui/ozone/platform/drm/host/drm_gpu_platform_support_host.h
index 25f37da..1bf4080 100644
--- a/ui/ozone/platform/drm/host/drm_gpu_platform_support_host.h
+++ b/ui/ozone/platform/drm/host/drm_gpu_platform_support_host.h
@@ -58,7 +58,7 @@ class DrmGpuPlatformSupportHost : public GpuPlatformSupportHost,
std::vector<GpuPlatformSupportHost*> handlers_; // Not owned.
DrmCursor* cursor_; // Not owned.
- ObserverList<ChannelObserver> channel_observers_;
+ base::ObserverList<ChannelObserver> channel_observers_;
};
} // namespace ui
diff --git a/ui/ozone/platform/drm/host/drm_native_display_delegate.h b/ui/ozone/platform/drm/host/drm_native_display_delegate.h
index 262db86..6b8e690 100644
--- a/ui/ozone/platform/drm/host/drm_native_display_delegate.h
+++ b/ui/ozone/platform/drm/host/drm_native_display_delegate.h
@@ -57,7 +57,7 @@ class DrmNativeDisplayDelegate : public NativeDisplayDelegate {
private:
DrmDisplayHostManager* display_manager_; // Not owned.
- ObserverList<NativeDisplayObserver> observers_;
+ base::ObserverList<NativeDisplayObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(DrmNativeDisplayDelegate);
};
diff --git a/ui/snapshot/screenshot_grabber.h b/ui/snapshot/screenshot_grabber.h
index 6a1e1cc..8461ce8 100644
--- a/ui/snapshot/screenshot_grabber.h
+++ b/ui/snapshot/screenshot_grabber.h
@@ -90,7 +90,7 @@ class SNAPSHOT_EXPORT ScreenshotGrabber {
// Task runner for blocking tasks.
scoped_refptr<base::TaskRunner> blocking_task_runner_;
- ObserverList<ScreenshotGrabberObserver> observers_;
+ base::ObserverList<ScreenshotGrabberObserver> observers_;
base::WeakPtrFactory<ScreenshotGrabber> factory_;
DISALLOW_COPY_AND_ASSIGN(ScreenshotGrabber);
diff --git a/ui/views/animation/bounds_animator.h b/ui/views/animation/bounds_animator.h
index 567e160..b5602ca 100644
--- a/ui/views/animation/bounds_animator.h
+++ b/ui/views/animation/bounds_animator.h
@@ -156,7 +156,7 @@ class VIEWS_EXPORT BoundsAnimator : public gfx::AnimationDelegate,
// Parent of all views being animated.
View* parent_;
- ObserverList<BoundsAnimatorObserver> observers_;
+ base::ObserverList<BoundsAnimatorObserver> observers_;
// All animations we create up with the same container.
scoped_refptr<gfx::AnimationContainer> container_;
diff --git a/ui/views/controls/menu/native_menu_win.h b/ui/views/controls/menu/native_menu_win.h
index 3cbc25f..3d4dcd1 100644
--- a/ui/views/controls/menu/native_menu_win.h
+++ b/ui/views/controls/menu/native_menu_win.h
@@ -137,7 +137,7 @@ class VIEWS_EXPORT NativeMenuWin : public MenuWrapper {
MenuAction menu_action_;
// A list of listeners to call when the menu opens.
- ObserverList<MenuListener> listeners_;
+ base::ObserverList<MenuListener> listeners_;
// Keep track of whether the listeners have already been called at least
// once.
diff --git a/ui/views/focus/focus_manager.h b/ui/views/focus/focus_manager.h
index c3e953f..4030158 100644
--- a/ui/views/focus/focus_manager.h
+++ b/ui/views/focus/focus_manager.h
@@ -371,7 +371,7 @@ class VIEWS_EXPORT FocusManager {
FocusChangeReason focus_change_reason_;
// The list of registered FocusChange listeners.
- ObserverList<FocusChangeListener, true> focus_change_listeners_;
+ base::ObserverList<FocusChangeListener, true> focus_change_listeners_;
// See description above getter.
bool is_changing_focus_;
diff --git a/ui/views/focus/widget_focus_manager.h b/ui/views/focus/widget_focus_manager.h
index 7dc5fa4..f87814a 100644
--- a/ui/views/focus/widget_focus_manager.h
+++ b/ui/views/focus/widget_focus_manager.h
@@ -53,7 +53,7 @@ class VIEWS_EXPORT WidgetFocusManager {
WidgetFocusManager();
~WidgetFocusManager();
- ObserverList<WidgetFocusChangeListener> focus_change_listeners_;
+ base::ObserverList<WidgetFocusChangeListener> focus_change_listeners_;
bool enabled_;
diff --git a/ui/views/widget/desktop_aura/desktop_window_tree_host_x11.h b/ui/views/widget/desktop_aura/desktop_window_tree_host_x11.h
index 94d4b1b..b726445 100644
--- a/ui/views/widget/desktop_aura/desktop_window_tree_host_x11.h
+++ b/ui/views/widget/desktop_aura/desktop_window_tree_host_x11.h
@@ -319,7 +319,7 @@ class VIEWS_EXPORT DesktopWindowTreeHostX11
DesktopWindowTreeHostX11* window_parent_;
std::set<DesktopWindowTreeHostX11*> window_children_;
- ObserverList<DesktopWindowTreeHostObserverX11> observer_list_;
+ base::ObserverList<DesktopWindowTreeHostObserverX11> observer_list_;
// The window shape if the window is non-rectangular.
gfx::XScopedPtr<_XRegion, gfx::XObjectDeleter<_XRegion, int, XDestroyRegion>>
diff --git a/ui/views/widget/widget.h b/ui/views/widget/widget.h
index 16d6640..9c21ea2 100644
--- a/ui/views/widget/widget.h
+++ b/ui/views/widget/widget.h
@@ -876,9 +876,9 @@ class VIEWS_EXPORT Widget : public internal::NativeWidgetDelegate,
internal::NativeWidgetPrivate* native_widget_;
- ObserverList<WidgetObserver> observers_;
+ base::ObserverList<WidgetObserver> observers_;
- ObserverList<WidgetRemovalsObserver> removals_observers_;
+ base::ObserverList<WidgetRemovalsObserver> removals_observers_;
// Non-owned pointer to the Widget's delegate. If a NULL delegate is supplied
// to Init() a default WidgetDelegate is created.
diff --git a/ui/views/win/windows_session_change_observer.cc b/ui/views/win/windows_session_change_observer.cc
index dbbe91d..627d4d0 100644
--- a/ui/views/win/windows_session_change_observer.cc
+++ b/ui/views/win/windows_session_change_observer.cc
@@ -99,7 +99,7 @@ class WindowsSessionChangeObserver::WtsRegistrationNotificationManager {
ClearCallback());
}
- ObserverList<WindowsSessionChangeObserver, true> observer_list_;
+ base::ObserverList<WindowsSessionChangeObserver, true> observer_list_;
scoped_ptr<gfx::SingletonHwndObserver> singleton_hwnd_observer_;
DISALLOW_COPY_AND_ASSIGN(WtsRegistrationNotificationManager);
diff --git a/ui/wm/core/compound_event_filter.h b/ui/wm/core/compound_event_filter.h
index c6f133f..26da51d8 100644
--- a/ui/wm/core/compound_event_filter.h
+++ b/ui/wm/core/compound_event_filter.h
@@ -80,7 +80,7 @@ class WM_EXPORT CompoundEventFilter : public ui::EventHandler {
void OnGestureEvent(ui::GestureEvent* event) override;
// Additional pre-target event handlers.
- ObserverList<ui::EventHandler, true> handlers_;
+ base::ObserverList<ui::EventHandler, true> handlers_;
DISALLOW_COPY_AND_ASSIGN(CompoundEventFilter);
};
diff --git a/ui/wm/core/cursor_manager.h b/ui/wm/core/cursor_manager.h
index 8288b22..168f104 100644
--- a/ui/wm/core/cursor_manager.h
+++ b/ui/wm/core/cursor_manager.h
@@ -80,7 +80,7 @@ class WM_EXPORT CursorManager : public aura::client::CursorClient,
// The cursor state to restore when the cursor is unlocked.
scoped_ptr<internal::CursorState> state_on_unlock_;
- ObserverList<aura::client::CursorClientObserver> observers_;
+ base::ObserverList<aura::client::CursorClientObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(CursorManager);
};
diff --git a/ui/wm/core/default_activation_client.h b/ui/wm/core/default_activation_client.h
index 726d886..b5511457 100644
--- a/ui/wm/core/default_activation_client.h
+++ b/ui/wm/core/default_activation_client.h
@@ -60,7 +60,7 @@ class WM_EXPORT DefaultActivationClient : public aura::client::ActivationClient,
// The window which was active before the currently active one.
aura::Window* last_active_;
- ObserverList<aura::client::ActivationChangeObserver> observers_;
+ base::ObserverList<aura::client::ActivationChangeObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(DefaultActivationClient);
};
diff --git a/ui/wm/core/focus_controller.h b/ui/wm/core/focus_controller.h
index 43d3c608b..be04b49 100644
--- a/ui/wm/core/focus_controller.h
+++ b/ui/wm/core/focus_controller.h
@@ -107,8 +107,9 @@ class WM_EXPORT FocusController : public aura::client::ActivationClient,
scoped_ptr<FocusRules> rules_;
- ObserverList<aura::client::ActivationChangeObserver> activation_observers_;
- ObserverList<aura::client::FocusChangeObserver> focus_observers_;
+ base::ObserverList<aura::client::ActivationChangeObserver>
+ activation_observers_;
+ base::ObserverList<aura::client::FocusChangeObserver> focus_observers_;
ScopedObserver<aura::Window, aura::WindowObserver> observer_manager_;
diff --git a/ui/wm/core/transient_window_manager.h b/ui/wm/core/transient_window_manager.h
index 6a17d9f..3f84420 100644
--- a/ui/wm/core/transient_window_manager.h
+++ b/ui/wm/core/transient_window_manager.h
@@ -98,7 +98,7 @@ class WM_EXPORT TransientWindowManager : public aura::WindowObserver {
bool show_on_parent_visible_;
bool ignore_visibility_changed_event_;
- ObserverList<TransientWindowObserver> observers_;
+ base::ObserverList<TransientWindowObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(TransientWindowManager);
};
diff --git a/ui/events/platform/platform_event_source.h b/ui/events/platform/platform_event_source.h
index 009476c..a20fe6b 100644
--- a/ui/events/platform/platform_event_source.h
+++ b/ui/events/platform/platform_event_source.h
@@ -81,10 +81,12 @@ class EVENTS_EXPORT PlatformEventSource {
void OnOverriddenDispatcherRestored();
// Use an ObserverList<> instead of an std::vector<> to store the list of
// dispatchers, so that adding/removing dispatchers during an event dispatch
// is well-defined.
- typedef ObserverList<PlatformEventDispatcher> PlatformEventDispatcherList;
+ typedef base::ObserverList<PlatformEventDispatcher>
+ PlatformEventDispatcherList;
PlatformEventDispatcherList dispatchers_;
PlatformEventDispatcher* overridden_dispatcher_;
@@ -92,7 +94,7 @@ class EVENTS_EXPORT PlatformEventSource {
// reset and a previous override-dispatcher has been restored.
bool overridden_dispatcher_restored_;
- ObserverList<PlatformEventObserver> observers_;
+ base::ObserverList<PlatformEventObserver> observers_;
DISALLOW_COPY_AND_ASSIGN(PlatformEventSource);
};
@@ -81,10 +81,12 @@ class EVENTS_EXPORT PlatformEventSource {
void OnOverriddenDispatcherRestored();
- // Use an ObserverList<> instead of an std::vector<> to store the list of
+ // Use an base::ObserverList<> instead of an std::vector<> to store the list
+ // of
// dispatchers, so that adding/removing dispatchers during an event dispatch
// is well-defined.